@@ -41,9 +41,7 @@ static PyObject* setColor( PyObject* self, PyObject* args )
         }
     }
 
-    Py_INCREF(Py_None);
     return Py_None;
-
 }
 
 /*
@@ -96,7 +94,6 @@ static PyObject* setAlpha( PyObject* self, PyObject* args )
         }
     }
 
-    Py_INCREF(Py_None);
     return Py_None;
 
 }
@@ -144,7 +141,6 @@ static PyObject* greyscale( PyObject* self, PyObject* args )
         }
     }
 
-    Py_INCREF(Py_None);
     return Py_None;
 }
 
@@ -174,7 +170,6 @@ static PyObject* invert( PyObject* self, PyObject* args )
         pixel = SDL_MapRGBA( format, 255-r, 255-g, 255-b, a );
         setPixelN(surface, pxcnt, pixel);
     }
-    Py_INCREF(Py_None);
     return Py_None;
 }
 
@@ -226,9 +221,7 @@ static PyObject* hue( PyObject* self, PyObject* args )
         pixel = SDL_MapRGBA( format, r, g, b, a );
         setPixelN(surface, pxcnt, pixel);
     }
-    Py_INCREF(Py_None);
     return Py_None;
-
 }
 
 /*
@@ -279,9 +272,7 @@ static PyObject* saturation( PyObject* self, PyObject* args )
         pixel = SDL_MapRGBA( format, r, g, b, a );
         setPixelN(surface, pxcnt, pixel);
     }
-    Py_INCREF(Py_None);
     return Py_None;
-
 }
 
 /*
@@ -332,9 +323,7 @@ static PyObject* value( PyObject* self, PyObject* args )
         pixel = SDL_MapRGBA( format, r, g, b, a );
         setPixelN(surface, pxcnt, pixel);
     }
-    Py_INCREF(Py_None);
     return Py_None;
-
 }
 
 static PyObject* lightness( PyObject* self, PyObject* args )
@@ -377,9 +366,8 @@ static PyObject* lightness( PyObject* self, PyObject* args )
         pixel = SDL_MapRGBA( format, r, g, b, a );
         setPixelN(surface, pxcnt, pixel);
     }
-    Py_INCREF(Py_None);
-    return Py_None;
 
+    return Py_None;
 }
 
 /* Color multiply */
@@ -417,7 +405,7 @@ static PyObject* multiply( PyObject* self, PyObject* args )
         pixel = SDL_MapRGBA( format, r, g, b, a );
         setPixelN(surface, pxcnt, pixel);
     }
-    Py_INCREF(Py_None);
+
     return Py_None;
 }
 
@@ -483,7 +471,6 @@ static PyObject* colorize( PyObject* self, PyObject* args )
 static PyObject* alphaMask( PyObject* self, PyObject* args )
 {
     PyObject* py_surface = NULL;
-    PyObject *out_py_surface = NULL;
     SDL_Surface *surface;
     SDL_Surface *target_surface;
     int w,h,x,y,mw,mh = 0;
@@ -551,9 +538,7 @@ static PyObject* alphaMask( PyObject* self, PyObject* args )
         }
     }
 
-    out_py_surface = PySurface_New( target_surface );
-    Py_INCREF( out_py_surface );
-    return Py_BuildValue("O", out_py_surface );
+    return PySurface_New( target_surface );
 }
 
 
