@@ -77,6 +77,7 @@ static PyObject* noise( PyObject* self, PyObject* args )
     Uint32 pixel;
     SDL_PixelFormat *format = NULL;
 
+    int cnt = 0;
     int value = 255;
     int density = 5;
     Uint8 r,g,b,a;
@@ -89,7 +90,31 @@ static PyObject* noise( PyObject* self, PyObject* args )
     getSurfaceAttrsSurf(py_surface, &w, &h, &format, &surface);
     //srand();
 
-    for( y = 0; y < h; y ++ ){
+    cnt = (w * h) / density;
+    for( ;; ){
+
+        x = (rand() % w);
+        y = (rand() % h);
+
+        pixel = getPixel(surface, x, y);
+        SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+
+        rnd = (value / 2) - (rand() % value);
+        tr = r + rnd;
+        tg = g + rnd;
+        tb = b + rnd;
+        r = clampUint8(tr);
+        g = clampUint8(tg);
+        b = clampUint8(tb);
+
+        pixel = SDL_MapRGBA( format, r, g, b, a );
+        setPixel(surface, x, y, pixel);
+
+        cnt--;
+        if(cnt < 0) break;
+    }
+
+/*    for( y = 0; y < h; y ++ ){
         for( x = 0; x < w; x ++ ){
             if( rand()%density != 0 ) continue;
             pixel = getPixel(surface, x, y);
@@ -107,8 +132,7 @@ static PyObject* noise( PyObject* self, PyObject* args )
             setPixel(surface, x, y, pixel);
         }
     }
-
-    Py_INCREF(Py_None);
+*/
     return Py_None;
 }
 
@@ -120,7 +144,7 @@ static PyObject* noiseBlur( PyObject* self, PyObject* args )
 {
     PyObject* py_surface = NULL;
     SDL_Surface *surface;
-    int w,h,x,y = 0;
+    int w,h,x,y;
     SDL_PixelFormat *format = NULL;
 
     int radius = 5;
@@ -144,15 +168,14 @@ static PyObject* noiseBlur( PyObject* self, PyObject* args )
             getPixel_RGBA(surface, dx, dy, &r, &g, &b, &a );
             if(blend){
                 getPixel_RGBA(surface, x, y, &tr, &tg, &tb, &ta );
-                r = (tr + r)/2;
-                g = (tg + g)/2;
-                b = (tb + b)/2;
+                r = (tr + r) / 2;
+                g = (tg + g) / 2;
+                b = (tb + b) / 2;
             }
             setPixel_RGBA(surface, x, y, r, g, b, a);
         }
     }
 
-    Py_INCREF(Py_None);
     return Py_None;
 }
 
@@ -195,7 +218,6 @@ static PyObject* scratch( PyObject* self, PyObject* args )
     }
 
     SDL_FreeSurface(surface_copy);
-    Py_INCREF(Py_None);
     return Py_None;
 }
 
@@ -234,7 +256,6 @@ static PyObject* pixelize( PyObject* self, PyObject* args )
         }
     }
 
-    Py_INCREF(Py_None);
     return Py_None;
 }
 
@@ -246,7 +267,7 @@ static PyObject* gradient( PyObject* self, PyObject* args )
 {
 
     SDL_Surface *surface = NULL;
-    PyObject *py_surface = NULL, *py_fcolor = NULL, *py_tcolor = NULL;
+    PyObject *py_fcolor = NULL, *py_tcolor = NULL;
     SDL_PixelFormat *format = NULL;
 
     Uint32 pixel;
@@ -299,9 +320,7 @@ static PyObject* gradient( PyObject* self, PyObject* args )
     }
     SDL_UnlockSurface (surface);
 
-    py_surface = PySurface_New( surface );
-    Py_INCREF( py_surface );
-    return Py_BuildValue("O", py_surface );
+    return PySurface_New( surface );
 }
 
 /*
@@ -319,7 +338,6 @@ static PyObject* shadow(PyObject* self, PyObject* args)
 
     SDL_Surface *target_surface = NULL;
     SDL_Surface *temp_surface = NULL;
-    PyObject *out_py_surface = NULL;
 
     Uint8 color[4];
 
@@ -380,9 +398,7 @@ static PyObject* shadow(PyObject* self, PyObject* args)
     /* Temp must be free */
     SDL_FreeSurface( temp_surface );
 
-    out_py_surface = PySurface_New( target_surface );
-    Py_INCREF( out_py_surface );
-    return Py_BuildValue("O", out_py_surface );
+    return PySurface_New( target_surface );
 }
 
 /*
@@ -449,7 +465,6 @@ static PyObject* hvBlur(PyObject* self, PyObject* args)
 
     SDL_FreeSurface(copy_surface);
 
-    Py_INCREF( Py_None );
     return Py_None;
 }
 
